;; Generated package description from wpuzzle.el  -*- no-byte-compile: t -*-
(define-package "wpuzzle" "1.1.0.20221212.231414" "find as many word in a given time" 'nil :commit "1cef20b60b6f165940454b1e100107371b9a3ea3" :url "https://elpa.gnu.org/packages/wpuzzle.html" :authors '(("Ivan Kanis" . "ivan@kanis.fr")) :maintainer '("Ivan Kanis" . "ivan@kanis.fr"))
